==> fasc-openapi-java-sdk-5.4.5.0524-sources.jar: com/fasc/open/api/event/auth/corp/CorpAuthorizeCallBackDto.java <==
package com.fasc.open.api.event.auth.corp;

import java.util.List;

/**
 * 企业授权事件
 */
public class CorpAuthorizeCallBackDto {

    private String eventTime;
    private String openCorpId;
    private String operatorId;
    private String authResult;
    private String authFailedReason;
    private List<String> authScope;
    private String corpIdentProcessStatus;
    private String corpIdentMethod;
    private String corpIdentFailedReason;
    private String operatorIdentProcessStatus;
    private String operatorIdentMethod;
    private String operatorIdentFailedReason;
    private String clientCorpId;
    private String clientUserId;
    private String memberId;

    public String getMemberId() {
        return memberId;
    }

    public void setMemberId(String memberId) {
        this.memberId = memberId;
    }

    public String getClientUserId() {
        return clientUserId;
    }

    public void setClientUserId(String clientUserId) {
        this.clientUserId = clientUserId;
    }

    public String getEventTime() {
        return eventTime;
    }

    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }

    public String getAuthResult() {
        return authResult;
    }

    public void setAuthResult(String authResult) {
        this.authResult = authResult;
    }

    public String getAuthFailedReason() {
        return authFailedReason;
    }

    public void setAuthFailedReason(String authFailedReason) {
        this.authFailedReason = authFailedReason;
    }

    public List<String> getAuthScope() {
        return authScope;
    }

    public void setAuthScope(List<String> authScope) {
        this.authScope = authScope;
    }

    public String getCorpIdentProcessStatus() {
        return corpIdentProcessStatus;
    }

    public void setCorpIdentProcessStatus(String corpIdentProcessStatus) {
        this.corpIdentProcessStatus = corpIdentProcessStatus;
    }

    public String getCorpIdentMethod() {
        return corpIdentMethod;
    }

    public void setCorpIdentMethod(String corpIdentMethod) {
        this.corpIdentMethod = corpIdentMethod;
    }

    public String getCorpIdentFailedReason() {
        return corpIdentFailedReason;
    }

    public void setCorpIdentFailedReason(String corpIdentFailedReason) {
        this.corpIdentFailedReason = corpIdentFailedReason;
    }

    public String getOperatorIdentProcessStatus() {
        return operatorIdentProcessStatus;
    }

    public void setOperatorIdentProcessStatus(String operatorIdentProcessStatus) {
        this.operatorIdentProcessStatus = operatorIdentProcessStatus;
    }

    public String getOperatorIdentMethod() {
        return operatorIdentMethod;
    }

    public void setOperatorIdentMethod(String operatorIdentMethod) {
        this.operatorIdentMethod = operatorIdentMethod;
    }

    public String getOperatorIdentFailedReason() {
        return operatorIdentFailedReason;
    }

    public void setOperatorIdentFailedReason(String operatorIdentFailedReason) {
        this.operatorIdentFailedReason = operatorIdentFailedReason;
    }

    public String getClientCorpId() {
        return clientCorpId;
    }

    public void setClientCorpId(String clientCorpId) {
        this.clientCorpId = clientCorpId;
    }
}

==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/event/auth/corp/CorpAuthorizeCallBackDto.java <==
package com.fasc.open.api.event.auth.corp;

import java.util.List;

/**
 * 企业授权事件
 */
public class CorpAuthorizeCallBackDto {

    private String eventTime;
    private String openCorpId;
    private String operatorId;
    private String authResult;
    private String authFailedReason;
    private List<String> authScope;
    private String corpIdentProcessStatus;
    private String corpIdentMethod;
    private String corpIdentFailedReason;
    private String operatorIdentProcessStatus;
    private String operatorIdentMethod;
    private String operatorIdentFailedReason;
    private String clientCorpId;
    private String clientUserId;
    private List<String> clientUserIds;
    private String memberId;
    private String existClientCorpId ;
    private String existOpenCorpId ;
    private String verifyStatus ;
    private String availableStatus ;

    public String getExistClientCorpId() {
        return existClientCorpId;
    }

    public void setExistClientCorpId(String existClientCorpId) {
        this.existClientCorpId = existClientCorpId;
    }

    public String getExistOpenCorpId() {
        return existOpenCorpId;
    }

    public void setExistOpenCorpId(String existOpenCorpId) {
        this.existOpenCorpId = existOpenCorpId;
    }

    public String getVerifyStatus() {
        return verifyStatus;
    }

    public void setVerifyStatus(String verifyStatus) {
        this.verifyStatus = verifyStatus;
    }

    public String getAvailableStatus() {
        return availableStatus;
    }

    public void setAvailableStatus(String availableStatus) {
        this.availableStatus = availableStatus;
    }

    public List<String> getClientUserIds() {
        return clientUserIds;
    }

    public void setClientUserIds(List<String> clientUserIds) {
        this.clientUserIds = clientUserIds;
    }

    public String getMemberId() {
        return memberId;
    }

    public void setMemberId(String memberId) {
        this.memberId = memberId;
    }

    public String getClientUserId() {
        return clientUserId;
    }

    public void setClientUserId(String clientUserId) {
        this.clientUserId = clientUserId;
    }

    public String getEventTime() {
        return eventTime;
    }

    public void setEventTime(String eventTime) {
        this.eventTime = eventTime;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }

    public String getAuthResult() {
        return authResult;
    }

    public void setAuthResult(String authResult) {
        this.authResult = authResult;
    }

    public String getAuthFailedReason() {
        return authFailedReason;
    }

    public void setAuthFailedReason(String authFailedReason) {
        this.authFailedReason = authFailedReason;
    }

    public List<String> getAuthScope() {
        return authScope;
    }

    public void setAuthScope(List<String> authScope) {
        this.authScope = authScope;
    }

    public String getCorpIdentProcessStatus() {
        return corpIdentProcessStatus;
    }

    public void setCorpIdentProcessStatus(String corpIdentProcessStatus) {
        this.corpIdentProcessStatus = corpIdentProcessStatus;
    }

    public String getCorpIdentMethod() {
        return corpIdentMethod;
    }

    public void setCorpIdentMethod(String corpIdentMethod) {
        this.corpIdentMethod = corpIdentMethod;
    }

    public String getCorpIdentFailedReason() {
        return corpIdentFailedReason;
    }

    public void setCorpIdentFailedReason(String corpIdentFailedReason) {
        this.corpIdentFailedReason = corpIdentFailedReason;
    }

    public String getOperatorIdentProcessStatus() {
        return operatorIdentProcessStatus;
    }

    public void setOperatorIdentProcessStatus(String operatorIdentProcessStatus) {
        this.operatorIdentProcessStatus = operatorIdentProcessStatus;
    }

    public String getOperatorIdentMethod() {
        return operatorIdentMethod;
    }

    public void setOperatorIdentMethod(String operatorIdentMethod) {
        this.operatorIdentMethod = operatorIdentMethod;
    }

    public String getOperatorIdentFailedReason() {
        return operatorIdentFailedReason;
    }

    public void setOperatorIdentFailedReason(String operatorIdentFailedReason) {
        this.operatorIdentFailedReason = operatorIdentFailedReason;
    }

    public String getClientCorpId() {
        return clientCorpId;
    }

    public void setClientCorpId(String clientCorpId) {
        this.clientCorpId = clientCorpId;
    }
}
